Package: biogeom
Type: Package
Title: Biological Geometries
Version: 1.5.2
Date: 2026-07-11
Authors@R: c(person(given="Peijian", family="Shi", email="pjshi@njfu.edu.cn", role=c("aut", "cre")),
        person(given=c("Johan"), family="Gielis", email="johan.gielis@uantwerpen.be", role=c("aut")),
        person(given=c("Brady K."), family="Quinn", email="brady.quinn@dfo-mpo.gc.ca", role=c("aut")))
Author: Peijian Shi [aut, cre],
  Johan Gielis [aut],
  Brady K. Quinn [aut]
Maintainer: Peijian Shi <pjshi@njfu.edu.cn>
Imports: bmp (>= 0.3), spatstat.geom (>= 2.4-0)
Description: Is used to simulate and fit biological geometries. 'biogeom' incorporates several novel universal parametric equations that can generate the profiles of bird eggs, flowers, linear and lanceolate leaves, seeds, starfish, and tree-rings (Gielis (2003) <doi:10.3732/ajb.90.3.333>; Shi et al. (2020) <doi:10.3390/sym12040645>), three growth-rate curves representing the ontogenetic growth trajectories of animals and plants against time, and the axially symmetrical and integral forms of all these functions (Shi et al. (2017) <doi:10.1016/j.ecolmodel.2017.01.012>; Shi et al. (2021) <doi:10.3390/sym13081524>). The optimization method proposed by Nelder and Mead (1965) <doi:10.1093/comjnl/7.4.308> was used to estimate model parameters. 'biogeom' includes several real data sets of the boundary coordinates of natural shapes, including avian eggs, fruit, lanceolate and ovate leaves, tree rings, seeds, and sea stars,and can be potentially applied to other natural shapes. 'biogeom' can quantify the conspecific or interspecific similarity of natural outlines, and provides information with important ecological and evolutionary implications for the growth and form of living organisms. Please see Shi et al. (2022) <doi:10.1111/nyas.14862> for details.
Depends: R (>= 4.3.0)
License: GPL (>= 2)
NeedsCompilation: no
Packaged: 2026-07-11 12:54:26 UTC; PEIJIAN SHI
Repository: CRAN
Date/Publication: 2026-07-11 13:20:02 UTC
Built: R 4.5.2; ; 2026-07-11 14:06:51 UTC; unix
