exportPattern("^[[:alpha:]]+")
importFrom("bmp", "read.bmp")
importFrom("spatstat.geom", "area", "area.owin", "as.polygonal", "im", "inside.owin", "intersect.owin", "is.empty", "owin", "quadratcount", "setminus.owin", "pairdist", "perimeter", "plot.ppp", "ppp", "transmat", "union.owin")
importFrom("grDevices", "dev.new", "graphics.off")
importFrom("graphics", "abline", "axis", "layout", "lines", "locator", "mtext", "par", "plot", "points", "polygon", "text", "title")
importFrom("stats", "confint", "integrate", "lm", "median", "na.omit", "optim", "quantile", "sd", "wilcox.test")